@@ -112,7 +112,8 @@ impl Node {
                 known_keys.extend(self.network_knowledge.prefix_map().section_keys());
                 known_keys.push(*self.network_knowledge.genesis_key());
 
-                if !msg_authority.verify_src_section_key_is_known(&known_keys) {
+                if !Self::verify_msg_can_be_trusted(msg_authority.clone(), msg.clone(), &known_keys)
+                {
                     warn!(
                         "Untrusted message ({:?}) dropped from {:?}: {:?} ",
                         msg_id, sender, msg
@@ -725,7 +726,7 @@ impl Node {
                 );
                 debug!("{}", LogMarker::DeviantsDetected);
 
-                return self.republish_data_for_suspicious_nodes(suspects).await;
+                return self.replicate_data_of_suspicious_nodes(suspects).await;
             }
             SystemMsg::NodeCmd(NodeCmd::ReplicateData(data_collection)) => {
                 info!("ReplicateData MsgId: {:?}", msg_id);
@@ -1073,17 +1074,23 @@ impl Node {
         cmds
     }
 
-    async fn republish_data_for_suspicious_nodes(
+    async fn replicate_data_of_suspicious_nodes(
         &self,
         suspects: BTreeSet<XorName>,
     ) -> Result<Vec<Cmd>> {
-        debug!("Republishing data for suspect nodes : {suspects:?}");
+        debug!("Replicating data of suspect nodes : {suspects:?}");
         let our_adults = self
             .network_knowledge
             .adults()
             .await
             .iter()
-            .map(|peer| peer.name())
+            .filter_map(|peer| {
+                if suspects.contains(&peer.name()) {
+                    None
+                } else {
+                    Some(peer.name())
+                }
+            })
             .collect::<BTreeSet<XorName>>();
 
         self.reorganize_data(BTreeSet::new(), suspects, our_adults)
