@@ -267,6 +267,11 @@ impl Node {
                 .cloned()
                 .collect::<Vec<Peer>>();
 
+            debug!(
+                "{:?}: {newly_suspect_nodes:?}",
+                LogMarker::SendSuspiciousNodesDetected
+            );
+
             for adult in valid_adults {
                 cmds.push(Cmd::SignOutgoingSystemMsg {
                     msg: SystemMsg::NodeEvent(NodeEvent::SuspiciousNodesDetected(
@@ -277,7 +282,6 @@ impl Node {
                         section_pk: *self.section_chain().await.last_key(),
                     },
                 });
-                debug!("{:?}", LogMarker::SendSuspiciousNodesDetected);
             }
         }
 
@@ -365,7 +369,7 @@ impl Node {
             };
 
             let self_status_change = if !old.is_elder && new.is_elder {
-                trace!("{}: {:?}", LogMarker::PromotedToElder, new.prefix);
+                info!("{}: {:?}", LogMarker::PromotedToElder, new.prefix);
                 NodeElderChange::Promoted
             } else if old.is_elder && !new.is_elder {
                 info!("{}", LogMarker::DemotedFromElder);
