@@ -10,24 +10,22 @@ mod link;
 
 pub(crate) use link::{Link, SendToOneError};
 
+use super::Peer;
+
 use qp2p::Endpoint;
 use std::{
     collections::{BTreeMap, BTreeSet},
     fmt::Debug,
-    net::SocketAddr,
     sync::Arc,
 };
 use tokio::sync::RwLock;
-use xor_name::XorName;
-
-type PeerId = (XorName, SocketAddr);
 
 /// This is tailored to the use-case of connecting on send.
 /// It keeps a Link instance per node, and is designed to make sure
 /// underlying I/O connection resources are not leaked, overused or left dangling.
 #[derive(Clone, Debug)]
 pub(crate) struct PeerLinks {
-    links: Arc<RwLock<BTreeMap<PeerId, Link>>>,
+    links: Arc<RwLock<BTreeMap<Peer, Link>>>,
     endpoint: Endpoint,
 }
 
@@ -38,7 +36,9 @@ impl PeerLinks {
             endpoint,
         }
     }
-    pub(crate) async fn linked_peers(&self) -> BTreeSet<PeerId> {
+
+    #[allow(unused)]
+    pub(crate) async fn linked_peers(&self) -> BTreeSet<Peer> {
         let links = self.links.read().await;
 
         links.keys().into_iter().cloned().collect()
@@ -46,11 +46,11 @@ impl PeerLinks {
 
     /// Any number of incoming qp2p:Connections can be added.
     /// We will eventually converge to the same one in our comms with the peer.
-    pub(crate) async fn add_incoming(&self, id: &PeerId, conn: qp2p::Connection) {
+    pub(crate) async fn add_incoming(&self, peer: &Peer, conn: qp2p::Connection) {
         {
             let link = self.links.read().await;
-            if let Some(c) = link.get(id) {
-                // peer id exists, add to it
+            if let Some(c) = link.get(peer) {
+                // peer exists, add to it
                 c.add(conn).await;
                 return;
             }
@@ -58,21 +58,22 @@ impl PeerLinks {
         }
 
         let mut links = self.links.write().await;
-        match links.get(id) {
+        match links.get(peer) {
             // someone else inserted in the meanwhile, add to it
             Some(c) => c.add(conn).await,
             // still not in list, go ahead and insert
             None => {
-                let link = Link::new_with(*id, self.endpoint.clone(), conn).await;
-                let _ = links.insert(*id, link);
+                let link = Link::new_with(*peer, self.endpoint.clone(), conn).await;
+                let _ = links.insert(*peer, link);
             }
         }
     }
 
-    pub(crate) async fn peer_is_connected(&self, id: &PeerId) -> bool {
+    #[allow(unused)]
+    pub(crate) async fn is_connected(&self, peer: &Peer) -> bool {
         let link = self.links.read().await;
-        if let Some(c) = link.get(id) {
-            // peer id exists, check if connected
+        if let Some(c) = link.get(peer) {
+            // peer exists, check if connected
             return c.is_connected().await;
         }
 
@@ -81,30 +82,31 @@ impl PeerLinks {
 
     /// This method is tailored to the use-case of connecting on send.
     /// I.e. it will not connect here, but on calling send on the returned link.
-    pub(crate) async fn get_or_create(&self, id: &PeerId) -> Link {
-        if let Some(link) = self.get(id).await {
+    pub(crate) async fn get_or_create(&self, peer: &Peer) -> Link {
+        if let Some(link) = self.get(peer).await {
             return link;
         }
 
-        // if id is not in list, the entire list needs to be locked
+        // if peer is not in list, the entire list needs to be locked
         // i.e. first comms to any node, will impact all sending at that instant..
         // however, first comms should be a minor part of total time spent using link,
         // so that is ok
         let mut links = self.links.write().await;
-        match links.get(id).cloned() {
+        match links.get(peer).cloned() {
             // someone else inserted in the meanwhile, so use that
             Some(link) => link,
             // still not in list, go ahead and create + insert
             None => {
-                let link = Link::new(*id, self.endpoint.clone());
-                let _ = links.insert(*id, link.clone());
+                let link = Link::new(*peer, self.endpoint.clone());
+                let _ = links.insert(*peer, link.clone());
                 link
             }
         }
     }
 
     /// Disposes of the link and all underlying resources.
-    pub(crate) async fn disconnect(&self, id: PeerId) {
+    #[allow(unused)]
+    pub(crate) async fn disconnect(&self, id: Peer) {
         let mut links = self.links.write().await;
         let link = match links.remove(&id) {
             // someone else inserted in the meanwhile, so use that
@@ -119,7 +121,7 @@ impl PeerLinks {
         link.disconnect().await;
     }
 
-    async fn get(&self, id: &PeerId) -> Option<Link> {
+    async fn get(&self, id: &Peer) -> Option<Link> {
         let links = self.links.read().await;
         links.get(id).cloned()
     }
